# Youtube SDK
## youtube_id
- String de `11 caracteres alfanuméricos (incluye '-' y '_')` identificador único de un video.
- `Example:`
1. `url:` https://www.youtube.com/watch?v=5ViMA_qDKTU
2. `youtube_id:` 5ViMA_qDKTU

## QuickStart
```bash
pip install yt-sdk
```

